@@ -20,10 +20,10 @@ class BaseCrawler(CachedRequests, SoupParser, ReducerMixin):
     urlorders = None
 
     
-    def __init__(self, *args, crawl_listener=None, **kwargs):
+    def __init__(self, *args, crawl_listener=None, collect_results=True, **kwargs):
         super().__init__(*args, **kwargs)
         self.crawl_listener = crawl_listener or (lambda module, event, context: True)
-
+        self.results = {} if collect_results else None
 
     def _resolve_link(self, link, action, response=None):
         if isinstance(action, UrlRenderAction): 
@@ -68,12 +68,12 @@ class BaseCrawler(CachedRequests, SoupParser, ReducerMixin):
         return links      
 
 
-    def _dispatch_extractor(self, action, meta, context):
+    def _dispatch_extractor(self, action, meta, response, context):
         extractset = {}
         if module := action.extractor:
             pat = r'^extract_(?P<ext>\w+)$'
             for g, func in find_function(module, pat):
-                extracted = filter_kwargs(func, meta=meta, soup=meta.soup, context=context)
+                extracted = filter_kwargs(func, meta=meta, soup=meta.soup, response=response, context=context)
                 extractset[g('ext')] = self.validate_extracted(extracted, func, meta)
         return extractset
 
@@ -206,9 +206,11 @@ class BaseCrawler(CachedRequests, SoupParser, ReducerMixin):
                         meta.update_responsemap(_responsemap)
 
                     ## parsing
-                    extracted = self._dispatch_extractor(action, meta, context)
+                    extracted = self._dispatch_extractor(action, meta, sub_response, context)
                     for ret in self._dispatch_parser(action, sub_response, extracted, meta, context):
                         self.pipeline(ret, action)
+                        if self.results is not None and ret:
+                            self.results.setdefault(action.name, []).append(ret)                   
 
                     if is_parsable is True:
                         if isinstance(action, UrlPatternAction):
