@@ -5,7 +5,7 @@ from navertoon.toon import test_navertoon
 from kofia.crawler import test_kofia
 from druginfo.crawler import test_druginfo
 from costores.crawler import coscores_search
-from naverplace.crawler import test_place
+from naverplace.test import test_naverplace_results_collecting
 
 
 def main():
@@ -42,8 +42,7 @@ def main():
         coscores_search(search=args.search)
 
     if args.appname == 'naverplace':
-        test_place()
-        
+        test_naverplace_results_collecting()
 
 
 if __name__ == '__main__':
